==> downloads.html?file=gigkalender_v1.2.63_076.zip: gigkalender/guestbook/backend_delGuestbookEntry.php <==
<?php
/*
    CREATIVE COMMONS - Attribution-No Derivative Works 3.0 Germany:
    - You may not alter, transform, or build upon this work.
    - Dieses Werk darf nicht bearbeitet oder in anderer Weise verändert werden.
*/
  $xUserRightDeleteGuestbookEntry = 1;
      echo '<p class="Headline">'.$L_Headline43.':</p>';
      if ( !$xUserRightDeleteGuestbookEntry ) { echo $L_015; }
      else
      {
        // Inhalt hier einfügen
          if ( isset($_POST['delGuestbookEntry']) )
      	 {
        	   if ($_POST['delGuestbookEntry']==$L_Button23)
        	   {
              $SQL_Befehl = "DELETE FROM ".$prefix."guestbook WHERE GuestbookID = '$GuestbookID'";
              $resultat = mysql_db_query($db_name, $SQL_Befehl);
              // Löschen erfolgreich
              if ($resultat) { echo $L_129; }
              // Löschen NICHT erfolgreich
              else { echo '<span class="Fehlermeldung">'.$L_ERROR_Guestbook_entry_could_NOT_be_deleted.'</span><br />'; }
        	   }
        	   // Löschvorgang abgebrochen
        	   if ($_POST['delGuestbookEntry']==$L_Button24)
        	   {
              echo $L_130;
        	   }
      	 }
      	 else
      	 {
        	   echo $L_132.'<br /><br />';
        	   echo '
              <form method="post" action="index.php?submenue=guestbook&amp;inhalt=backend_delGuestbookEntry">
                <fieldset>
                  <input name="delGuestbookEntry" type="submit" value="'.$L_Button23.'" class="button" />
                  <input name="delGuestbookEntry" type="submit" value="'.$L_Button24.'" class="button" />
                  <input name="GuestbookID" type="hidden" value="'.$GuestbookID.'" />
                  <input type="hidden" name="http-equiv" value="backend_showAllGuestbookEntries" />
                </fieldset>
        	     </form>
            ';
      	 }
        // Inhalt zuende
      }
    ?>

==> downloads.html?file=gigkalender_v1.2.64_009.zip: gigkalender/guestbook/backend_delGuestbookEntry.php <==
<?php
/*
    CREATIVE COMMONS - Attribution-No Derivative Works 3.0 Germany:
    - You may not alter, transform, or build upon this work.
    - Dieses Werk darf nicht bearbeitet oder in anderer Weise verändert werden.
*/
  $xUserRightDeleteGuestbookEntry = 1;
      echo '<p class="Headline">'.$L_Headline43.':</p>';
      if ( !$xUserRightDeleteGuestbookEntry ) { echo $L_015; }
      else
      {
        // Inhalt hier einfügen
          if ( isset($_POST['delGuestbookEntry']) )
      	 {
        	   if ($_POST['delGuestbookEntry']==$L_Button23)
        	   {
              $SQL_Befehl = "DELETE FROM ".$prefix."guestbook WHERE GuestbookID = '$GuestbookID'";
              $resultat = mysql_db_query($db_name, $SQL_Befehl);
              // Löschen erfolgreich
              if ($resultat) { echo $L_129; }
              // Löschen NICHT erfolgreich
              else { echo '<span class="ErrorMessage">'.$L_ERROR_Guestbook_entry_could_NOT_be_deleted.'</span><br />'; }
        	   }
        	   // Löschvorgang abgebrochen
        	   if ($_POST['delGuestbookEntry']==$L_Button24)
        	   {
              echo $L_130;
        	   }
      	 }
      	 else
      	 {
        	   echo $L_132.'<br /><br />';
        	   echo '
              <form method="post" action="index.php?submenue=guestbook&amp;inhalt=backend_delGuestbookEntry" accept-charset="UTF-8">
                <fieldset>
                  <input name="delGuestbookEntry" type="submit" value="'.$L_Button23.'" class="button" />
                  <input name="delGuestbookEntry" type="submit" value="'.$L_Button24.'" class="button" />
                  <input name="GuestbookID" type="hidden" value="'.$GuestbookID.'" />
                  <input type="hidden" name="http-equiv" value="backend_showAllGuestbookEntries" />
                </fieldset>
        	     </form>
            ';
      	 }
        // Inhalt zuende
      }
    ?>
